=== modified file 'bzrlib/controldir.py'
--- bzrlib/controldir.py	2011-02-24 16:13:39 +0000
+++ bzrlib/controldir.py	2011-02-24 16:21:50 +0000
@@ -691,6 +691,15 @@
             result.append(fmt)
         return result + self._get_extra()
 
+    def _get_all_modules(self):
+        """Return a set of the modules providing objects."""
+        modules = set()
+        for name in self.keys():
+            modules.add(self._get_module(name))
+        for getter in self._extra_formats:
+            modules.add(getter.get_module())
+        return modules
+
 
 class ControlDirFormat(object):
     """An encapsulation of the initialization and open routines for a format.

=== modified file 'bzrlib/registry.py'
--- bzrlib/registry.py	2011-02-24 16:13:39 +0000
+++ bzrlib/registry.py	2011-02-24 16:21:50 +0000
@@ -35,6 +35,10 @@
     def __init__(self, obj):
         self._obj = obj
 
+    def get_module(self):
+        """Get the module the object was loaded from."""
+        return self._obj.__module__
+
     def get_obj(self):
         """Get the object that was saved at creation time"""
         return self._obj
@@ -54,6 +58,11 @@
         self._imported = False
         super(_LazyObjectGetter, self).__init__(None)
 
+    def get_module(self):
+        """Get the module the referenced object will be loaded from.
+        """
+        return self._module_name
+
     def get_obj(self):
         """Get the referenced object.
 
@@ -163,6 +172,14 @@
         """
         return self._dict[self._get_key_or_default(key)].get_obj()
 
+    def _get_module(self, key):
+        """Return the module the object will be or was loaded from.
+
+        :param key: The key to obtain the module for.
+        :return: The name of the module
+        """
+        return self._dict[key].get_module()
+
     def get_prefix(self, fullname):
         """Return an object whose key is a prefix of the supplied value.
 

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2011-02-24 16:13:39 +0000
+++ bzrlib/repository.py	2011-02-24 16:21:50 +0000
@@ -4548,10 +4548,4 @@
         return
 
 
-def _get_repository_modules():
-    """Return a list of the modules providing repositories."""
-    modules = set()
-    for objgetter in format_registry._get_all():
-        modules.add(objgetter.__module__)
-    return modules
 

=== modified file 'bzrlib/tests/per_interrepository/__init__.py'
--- bzrlib/tests/per_interrepository/__init__.py	2011-02-24 16:09:13 +0000
+++ bzrlib/tests/per_interrepository/__init__.py	2011-02-24 16:21:50 +0000
@@ -33,7 +33,7 @@
     )
 
 from bzrlib.repository import (
-    _get_repository_modules,
+    format_registry,
     InterDifferingSerializer,
     InterRepository,
     )
@@ -101,7 +101,7 @@
     # Gather extra scenarios from the repository implementations,
     # as InterRepositories can be used by Repository implementations
     # they aren't aware of.
-    for module in _get_repository_modules():
+    for module in format_registry._get_all_modules():
         try:
             get_extra_interrepo_test_combinations = getattr(module,
                 "get_extra_interrepo_test_combinations")

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2011-02-24 16:01:22 +0000
+++ bzrlib/transport/__init__.py	2011-02-24 16:21:50 +0000
@@ -83,10 +83,7 @@
     modules = set()
     for prefix, factory_list in transport_list_registry.items():
         for factory in factory_list:
-            if hasattr(factory, "_module_name"):
-                modules.add(factory._module_name)
-            else:
-                modules.add(factory._obj.__module__)
+            modules.add(factory.get_module())
     # Add chroot and pathfilter directly, because there is no handler
     # registered for it.
     modules.add('bzrlib.transport.chroot')

